
# Contents

# Examples

## Hash data

```python


```

## Encode Call Data of a Function

## Decode Call Data of a Function

## Decode Output of a Function

## Decode An Event

## Get Contract ABI

## Get Function ABI

## Get Event ABI

